You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@shindig.apache.org by do...@apache.org on 2008/01/28 22:42:21 UTC

svn commit: r616061 - in /incubator/shindig/trunk/features: core/ dynamic-height/ flash/ minimessage/ rpc/ settitle/ skins/ tabs/ views/

Author: doll
Date: Mon Jan 28 13:42:20 2008
New Revision: 616061

URL: http://svn.apache.org/viewvc?rev=616061&view=rev
Log:
Last cleanup of js comments in shindig, it now matches the spec. 

Note: There will probably be follow up changes to take some of the longer comments back out of shindig and have the js code instead point to the more verbose spec. The spec will also continue to iterate outside of shindig. 



Modified:
    incubator/shindig/trunk/features/core/io.js
    incubator/shindig/trunk/features/core/json.js
    incubator/shindig/trunk/features/core/prefs.js
    incubator/shindig/trunk/features/core/util.js
    incubator/shindig/trunk/features/dynamic-height/dynamic-height.js
    incubator/shindig/trunk/features/flash/flash.js
    incubator/shindig/trunk/features/minimessage/minimessage.js
    incubator/shindig/trunk/features/rpc/rpc.js
    incubator/shindig/trunk/features/settitle/settitle.js
    incubator/shindig/trunk/features/skins/skins.js
    incubator/shindig/trunk/features/tabs/tabs.js
    incubator/shindig/trunk/features/views/views.js

Modified: incubator/shindig/trunk/features/core/io.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/core/io.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/core/io.js (original)
+++ incubator/shindig/trunk/features/core/io.js Mon Jan 28 13:42:20 2008
@@ -116,6 +116,8 @@
      *     Additional
      *     <a href="gadgets.io.RequestParameters.html">parameters</a>
      *     to pass to the request
+     *
+     * @member gadgets.io
      */
     makeRequest : function (url, callback, opt_params) {
       // TODO: This method also needs to respect all members of
@@ -133,11 +135,14 @@
     },
 
     /**
-     * Converts an input object into a url encoded data string (key=value&...)
+     * Converts an input object into a URL-encoded data string.
+     * (key=value&amp;...)
      *
      * @param {Object} fields The post fields you wish to encode
-     * @return {String} The processed post data. This will include a trialing
-     *    ampersand (&).
+     * @return {String} The processed post data; this will include a trailing
+     *    ampersand (&)
+     *
+     * @member gadgets.io
      */
     encodeValues : function (fields) {
       var buf = [];
@@ -151,10 +156,12 @@
     },
 
     /**
-     * Gets the proxy version of the passed in url.
+     * Gets the proxy version of the passed-in URL.
+     *
+     * @param {String} url The URL to get the proxy URL for
+     * @return {String} The proxied version of the URL
      *
-     * @param {String} url The url to get the proxy url for.
-     * @return {String} The proxied version of the url.
+     * @member gadgets.io
      */
     getProxyUrl : function (url) {
       return config.proxyUrl.replace("%url%", encodeURIComponent(url));
@@ -163,7 +170,7 @@
     /**
      * Initializes fetchers
      *
-     * @param {Object} configuration Configuration settings.
+     * @param {Object} configuration Configuration settings
      *     Required:
      *       - proxyUrl: The url for content proxy requests. Include %url%
      *           as a placeholder for the actual url.
@@ -197,6 +204,8 @@
    * defaults to <code>MethodType.GET</a></code>.
    * Specified as a
    * <a href="gadgets.io.MethodType.html">MethodType</a>.
+   *
+   * @member gadgets.io.RequestParameters
    */
    METHOD : 'METHOD',
 
@@ -206,20 +215,26 @@
    * Specified as a
    * <a href="gadgets.io.ContentType.html">
    * ContentType</a>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   CONTENT_TYPE : "CONTENT_TYPE",
 
   /**
-   * The data to send to the URL using the POST method.
-   * Specified as a <code>String</code>
-   * Defaults to null.
+   * The data to send to the URL using the POST method;
+   * defaults to null.
+   * Specified as a <code>String</code>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   POST_DATA : "POST_DATA",
 
   /**
-   * The HTTP headers to send to the URL.
-   * Specified as a <code>Map.<String,String></code>
-   * Defaults to null.
+   * The HTTP headers to send to the URL;
+   * defaults to null.
+   * Specified as a <code>Map.&lt;String,String&gt;</code>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   HEADERS : "HEADERS",
 
@@ -229,6 +244,8 @@
    * Specified as an
    * <a href="gadgets.io.AuthorizationType.html">
    * AuthorizationType</a>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   AUTHORIZATION : 'AUTHORIZATION',
 
@@ -237,6 +254,8 @@
    * If the content is a feed, the number of entries to fetch;
    * defaults to 3.
    * Specified as a <code>Number</code>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   NUM_ENTRIES : 'NUM_ENTRIES',
 
@@ -244,6 +263,8 @@
    * If the content is a feed, whether to fetch summaries for that feed;
    * defaults to false.
    * Specified as a <code>Boolean</code>.
+   *
+   * @member gadgets.io.RequestParameters
    */
   GET_SUMMARIES : 'GET_SUMMARIES'
 };
@@ -258,26 +279,33 @@
  * @name gadgets.io.MethodType
  */
 gadgets.io.MethodType = {
-  /** The default type. */
+  /**
+   * The default type.
+   * @member gadgets.io.MethodType
+   */
   GET : 'GET',
 
   /**
-  * Not supported by all containers.
-  */
+   * Not supported by all containers.
+   * @member gadgets.io.MethodType
+   */
   POST : 'POST',
 
   /**
-  * Not supported by all containers.
-  */
+   * Not supported by all containers.
+   * @member gadgets.io.MethodType
+   */
   PUT : 'PUT',
 
   /**
-  * Not supported by all containers.
-  */
+   * Not supported by all containers.
+   * @member gadgets.io.MethodType
+   */
   DELETE : 'DELETE',
 
   /**
    * Not supported by all containers.
+   * @member gadgets.io.MethodType
    */
   HEAD : 'HEAD'
 };
@@ -293,22 +321,26 @@
  */
 gadgets.io.ContentType = {
   /**
-   * Returns text, used for fetching html.
+   * Returns text; used for fetching HTML.
+   * @member gadgets.io.ContentType
    */
   TEXT : 'TEXT',
 
   /**
-   * Returns a dom object, used for fetching xml.
+   * Returns a DOM object; used for fetching XML.
+   * @member gadgets.io.ContentType
    */
   DOM : 'DOM',
 
   /**
-   * Returns a json object.
+   * Returns a JSON object.
+   * @member gadgets.io.ContentType
    */
   JSON : 'JSON',
 
   /**
-   * Returns a json representation of a feed.
+   * Returns a JSON representation of a feed.
+   * @member gadgets.io.ContentType
    */
   FEED : 'FEED'
 };
@@ -323,12 +355,21 @@
  * @name gadgets.io.AuthorizationType
  */
 gadgets.io.AuthorizationType = {
-  /** No authorization */
+  /**
+   * No authorization.
+   * @member gadgets.io.AuthorizationType
+   */
   NONE : 'NONE',
 
-  /** The request will be signed by the container */
+  /**
+   * The request will be signed by the container.
+   * @member gadgets.io.AuthorizationType
+   */
   SIGNED : 'SIGNED',
 
-  /** The container will use full authentication */
+  /**
+   * The container will use full authentication.
+   * @member gadgets.io.AuthorizationType
+   */
   AUTHENTICATED : 'AUTHENTICATED'
 };

Modified: incubator/shindig/trunk/features/core/json.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/core/json.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/core/json.js (original)
+++ incubator/shindig/trunk/features/core/json.js Mon Jan 28 13:42:20 2008
@@ -129,10 +129,12 @@
         license: 'http://www.JSON.org/license.html',
 
         /**
-         * Stringifies a JavaScript value, producing a JSON text.
+         * Converts a JavaScript value to a JSON string.
          *
-         * @param {Object} v The object to stringify.
-         * @return {String} The stringified object.
+         * @param {Object} v The object to convert
+         * @return {String} The JSON equivalent
+	 *
+         * @member gadgets.json
          */
         stringify: function (v) {
             var f = s[typeof v];
@@ -146,13 +148,14 @@
         },
 
         /**
-         * Parses a JSON text, producing a JavaScript value.
-         * It returns false if there is a syntax error.
+         * Parses a JSON string, producing a JavaScript value.
          *
-         * @param {String} text The string to transform into an object. Usually
-         *     the result of a previous stringify call.
-         * @return {Object} The object parsed from the passed in text. False if
-         *     an error occurred.
+         * @param {String} text The string to transform into an object &mdash;
+	 *     usually the result of a previous stringify call
+         * @return {Object} The object parsed from the passed in text; false if
+         *     an error occurred
+	 *
+         * @member gadgets.json
          */
         parse: function (text) {
             try {

Modified: incubator/shindig/trunk/features/core/prefs.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/core/prefs.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/core/util.js (original)
+++ incubator/shindig/trunk/features/core/util.js Mon Jan 28 13:42:20 2008
@@ -20,14 +20,14 @@
 
 /**
  * @static
- * @class Provides general purpose utility functions.
+ * @class Provides general-purpose utility functions.
  * @name gadgets.util
  */
 
 gadgets.util = function() {
   /**
-   * Parses url parameters into an object.
-   * @return {Array.<String>} the parameters.
+   * Parses URL parameters into an object.
+   * @return {Array.&lt;String&gt;} The parameters
    */
   function parseUrlParams() {
     // Get settings from url, 'hash' takes precedence over 'search' component
@@ -53,9 +53,10 @@
   return /** @scope gadgets.util */ {
 
     /**
-     * Gets the url parameters.
+     * Gets the URL parameters.
      *
-     * @return {Object} Parameters passed into the query string.
+     * @return {Object} Parameters passed into the query string
+     * @member gadgets.util
      */
     getUrlParameters : function () {
       if (parameters !== null) {
@@ -81,15 +82,19 @@
     },
 
     /**
-     * Creates a closure which is suitable for passing as a callback.
+     * Creates a closure that is suitable for passing as a callback.
+     * Any number of arguments
+     * may be passed to the callback;
+     * they will be received in the order they are passed in.
      *
-     * @param {Object} scope The execution scope. May be null if there is no
+     * @param {Object} scope The execution scope; may be null if there is no
      *     need to associate a specific instance of an object with this
-     *     callback.
-     * @param {Function} callback The callback to invoke when this is run.
-     *     any arguments passed in will be passed after your initial arguments.
-     * @param {Object} var_args Any number of arguments may be passed to the
-     *     callback. They will be received in the order they are passed in.
+     *     callback
+     * @param {Function} callback The callback to invoke when this is run;
+     *     any arguments passed in will be passed after your initial arguments
+     * @param {Object} var_args Initial arguments to be passed to the callback
+     *
+     * @member gadgets.util
      */
     makeClosure : function (scope, callback, var_args) {
       // arguments isn't a real array, so we copy it into one.
@@ -109,8 +114,10 @@
     /**
      * Gets the feature parameters.
      *
-     * @param {String} feature The feature to get parameters for.
-     * @return {Object} The parameters for the given feature, or null.
+     * @param {String} feature The feature to get parameters for
+     * @return {Object} The parameters for the given feature, or null
+     *
+     * @member gadgets.util
      */
     getFeatureParameters : function (feature) {
       return typeof features[feature] === "undefined"
@@ -120,8 +127,10 @@
     /**
      * Returns whether the current feature is supported.
      *
-     * @param {String} feature The feature to test for.
-     * @return {Boolean} True if the feature is supported.
+     * @param {String} feature The feature to test for
+     * @return {Boolean} True if the feature is supported
+     *
+     * @member gadgets.util
      */
     hasFeature : function (feature) {
       return typeof features[feature] === "undefined";
@@ -129,7 +138,9 @@
 
     /**
      * Registers an onload handler.
-     * @param {Function} callback The handler to run.
+     * @param {Function} callback The handler to run
+     *
+     * @member gadgets.util
      */
     registerOnLoadHandler : function (callback) {
       onLoadHandlers.push(callback);

Modified: incubator/shindig/trunk/features/dynamic-height/dynamic-height.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/dynamic-height/dynamic-height.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/dynamic-height/dynamic-height.js (original)
+++ incubator/shindig/trunk/features/dynamic-height/dynamic-height.js Mon Jan 28 13:42:20 2008
@@ -36,6 +36,7 @@
  * See: http://www.quirksmode.org/viewport/compatibility.html for more
  * information.
  * @returns {Object} An object with width and height properties.
+ * @member gadgets.window
  */
 gadgets.window.getViewportDimensions = function() {
   var x,y;
@@ -63,6 +64,7 @@
  * Adjusts the gadget height
  * @param {Number} opt_height An optional preferred height in pixels. If not
  *     specified, will attempt to fit the gadget to its content.
+ * @member gadgets.window
  */
 gadgets.window.adjustHeight = function(opt_height) {
   var newHeight = parseInt(opt_height, 10);

Modified: incubator/shindig/trunk/features/flash/flash.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/flash/flash.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/flash/flash.js (original)
+++ incubator/shindig/trunk/features/flash/flash.js Mon Jan 28 13:42:20 2008
@@ -34,6 +34,8 @@
  * Detects Flash Player and its major version.
  * @return {Number} The major version of Flash Player
  *                  or 0 if Flash is not supported.
+ *
+ * @member gadgets.flash
  */
 gadgets.flash.getMajorVersion = function() {
   var flashMajorVersion = 0;
@@ -68,6 +70,8 @@
  *     parameter. All attributes will be passed through to the flash movie on
  *     creation.
  * @return {Boolean} Whether the function call completes successfully.
+ *
+ * @member gadgets.flash
  */
 // TODO The shindig implementation does not match the spec described above!
 gadgets.flash.embedFlash = function(swfUrl, swfContainer, opt_params) {
@@ -167,6 +171,8 @@
  * Injects a cached Flash file into the DOM tree.
  * Accepts the same parameters as gadgets.flash.embedFlash does.
  * @return {Boolean} Whether the function call completes successfully.
+ *
+ * @member gadgets.flash
  */
 gadgets.flash.embedCachedFlash = function() {
   var args = Array.prototype.slice.call(arguments);

Modified: incubator/shindig/trunk/features/minimessage/minimessage.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/minimessage/minimessage.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/minimessage/minimessage.js (original)
+++ incubator/shindig/trunk/features/minimessage/minimessage.js Mon Jan 28 13:42:20 2008
@@ -33,7 +33,7 @@
  *
  * @description Used to create messages that will appear to the user within the
  *     gadget.
- * @param {String} opt_moduleId Optional module Id.
+ * @param {String} opt_moduleId Optional module Id
  * @param {Element} opt_container Optional HTML container element where
  *                                mini-messages will appear.
  */
@@ -47,7 +47,7 @@
 /**
  * Helper function that creates a container HTML element where mini-messages
  * will be appended to.  The container element is inserted at the top of gadget.
- * @return {Element} An HTML div element as the message container.
+ * @return {Element} An HTML div element as the message container
  * @private
  */
 gadgets.MiniMessage.prototype.createContainer_ = function() {
@@ -66,7 +66,7 @@
 
 /**
  * Helper function that dynamically inserts CSS rules to the page.
- * @param {String} cssText CSS rules to inject.
+ * @param {String} cssText CSS rules to inject
  * @private
  */
 gadgets.MiniMessage.addCSS_ = function(cssText) {
@@ -85,8 +85,8 @@
 
 /**
  * Helper function that expands a class name into two class names.
- * @param {String} label The CSS class name.
- * @return {String} "X Xn", with n is the ID of this module.
+ * @param {String} label The CSS class name
+ * @return {String} "X Xn", with n is the ID of this module
  * @private
  */
 gadgets.MiniMessage.prototype.cascade_ = function(label) {
@@ -97,10 +97,10 @@
  * Helper function that returns a function that dismisses a message by removing
  * the message table element from the DOM.  The action is cancelled if the
  * callback function returns false.
- * @param {Element} element HTML element to remove.
+ * @param {Element} element HTML element to remove
  * @param {Function} opt_callback Optional callback function to be called when
  *                                the message is dismissed.
- * @return {Function} A function that dismisses the specified message.
+ * @return {Function} A function that dismisses the specified message
  * @private
  */
 gadgets.MiniMessage.prototype.dismissFunction_ = function(element, opt_callback) {
@@ -117,13 +117,13 @@
 };
 
 /**
- * Creates a dismissible message with an [x] icon allowing users to dismiss
- * the message. When the message is dismissed, it is removed from the DOM,
- * and the optional callback function is called, if defined.
- * @param {String | Object} message The message as an HTML string or DOM element.
+ * Creates a dismissible message with an [[]x] icon that allows users to dismiss
+ * the message. When the message is dismissed, it is removed from the DOM
+ * and the optional callback function, if defined, is called.
+ * @param {String | Object} message The message as an HTML string or DOM element
  * @param {Function} opt_callback Optional callback function to be called when
- *                                the message is dismissed.
- * @return {Element} HTML element of the created message.
+ *                                the message is dismissed
+ * @return {Element} HTML element of the created message
  */
 gadgets.MiniMessage.prototype.createDismissibleMessage = function(message,
                                                          opt_callback) {
@@ -142,14 +142,15 @@
 };
 
 /**
- * Creates a timer message that displays for x seconds. When the timer expires,
- * the message is dismissed, and the optional callback function is executed.
- * @param {String | Object} message The message as an HTML string or DOM element.
+ * Creates a message that displays for the specified number of seconds.
+ * When the timer expires,
+ * the message is dismissed and the optional callback function is executed.
+ * @param {String | Object} message The message as an HTML string or DOM element
  * @param {number} seconds Number of seconds to wait before dismissing
- *                         the message.
+ *                         the message
  * @param {Function} opt_callback Optional callback function to be called when
- *                                the message is dismissed.
- * @return {Element} HTML element of the created message.
+ *                                the message is dismissed
+ * @return {Element} HTML element of the created message
  */
 gadgets.MiniMessage.prototype.createTimerMessage = function(message, seconds,
                                                             opt_callback) {
@@ -160,9 +161,9 @@
 
 /**
  * Creates a static message that can only be dismissed programmatically
- * by calling dismissMessage().
- * @param {String | Object} message The message as an HTML string or DOM element.
- * @return {Element} HTML element of the created message.
+ * (by calling dismissMessage()).
+ * @param {String | Object} message The message as an HTML string or DOM element
+ * @return {Element} HTML element of the created message
  */
 gadgets.MiniMessage.prototype.createStaticMessage = function(message) {
   // Generate and assign unique DOM ID to table.
@@ -204,7 +205,7 @@
 
 /**
  * Dismisses the specified message.
- * @param {Element} message HTML element of the message to remove.
+ * @param {Element} message HTML element of the message to remove
  */
 gadgets.MiniMessage.prototype.dismissMessage = function(message) {
   this.dismissFunction_(message)();

Modified: incubator/shindig/trunk/features/rpc/rpc.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/rpc/rpc.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/rpc/rpc.js (original)
+++ incubator/shindig/trunk/features/rpc/rpc.js Mon Jan 28 13:42:20 2008
@@ -34,6 +34,8 @@
      * Registers an RPC service.
      * @param {String} serviceName Service name to register.
      * @param {Function} handler Service handler.
+     *
+     * @member gadgets.rpc
      */
     register: function(serviceName, handler) {
       // TODO
@@ -42,6 +44,8 @@
     /**
      * Unregisters an RPC service.
      * @param {String} serviceName Service name to unregister.
+     *
+     * @member gadgets.rpc
      */
     unregister: function(serviceName) {
       // TODO
@@ -51,6 +55,8 @@
      * Registers a default service handler to processes all unknown
      * RPC calls which fail silently by default.
      * @param {Function} handler Service handler.
+     *
+     * @member gadgets.rpc
      */
     registerDefault: function(handler) {
       // TODO
@@ -59,6 +65,8 @@
     /**
      * Unregisters the default service handler. Future unknown RPC
      * calls will fail silently.
+     *
+     * @member gadgets.rpc
      */
     unregisterDefault: function() {
       // TODO
@@ -72,6 +80,8 @@
      * @param {Function|null} callback Callback function (if any) to process
      *                                 the return value of the RPC request.
      * @param {*} var_args Parameters for the RPC request.
+     *
+     * @member gadgets.rpc
      */
     call: function(targetId, serviceName, callback, var_args) {
       // TODO

Modified: incubator/shindig/trunk/features/settitle/settitle.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/settitle/settitle.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/settitle/settitle.js (original)
+++ incubator/shindig/trunk/features/settitle/settitle.js Mon Jan 28 13:42:20 2008
@@ -23,17 +23,13 @@
 
 var gadgets = gadgets || {};
 
-/**
- * @static
- * @class Provides operations for getting information about and modifying the
- *     window the gadget is placed in.
- * @name gadgets.window
- */
+/* NOTE: no class comment because one already exists in dynamic-height */
 gadgets.window = gadgets.window || {};
 
 /**
  * Sets the gadget title.
  * @param {String} title The preferred title.
+ * @scope gadgets.window
  */
 gadgets.window.setTitle = function(title) {
   var modId = 'remote_module_' + (new gadgets.Prefs()).getModuleId();

Modified: incubator/shindig/trunk/features/skins/skins.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/skins/skins.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/skins/skins.js (original)
+++ incubator/shindig/trunk/features/skins/skins.js Mon Jan 28 13:42:20 2008
@@ -37,6 +37,8 @@
  *    keys are defined in <a href="gadgets.skins.Property.html"><code>
  *    gadgets.skins.Property</code></a>
  * @return {String} The data
+ *
+ * @member gadgets.skins
  */
 gadgets.skins.getProperty = function(propertyKey) {};
 
@@ -50,12 +52,27 @@
  * @name gadgets.skins.Property
  */
 gadgets.skins.Property = {
-  /** An image to use in the background of the gadget */
+  /**
+   * An image to use in the background of the gadget.
+   * @member gadgets.skins.Property
+   */
   BG_IMAGE : 'BG_IMAGE',
-  /** The color of the background of the gadget */
+
+  /**
+   * The color of the background of the gadget.
+   * @member gadgets.skins.Property
+   */
   BG_COLOR : 'BG_COLOR',
-  /** The color that the main font should use */
+
+  /**
+   * The color that the main font should use.
+   * @member gadgets.skins.Property
+   */
   FONT_COLOR : 'FONT_COLOR',
-  /** The color that anchor tags should use */
+
+  /**
+   * The color that anchor tags should use.
+   * @member gadgets.skins.Property
+   */
   ANCHOR_COLOR : 'ANCHOR_COLOR'
-};
\ No newline at end of file
+};

Modified: incubator/shindig/trunk/features/tabs/tabs.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/tabs/tabs.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/tabs/tabs.js (original)
+++ incubator/shindig/trunk/features/tabs/tabs.js Mon Jan 28 13:42:20 2008
@@ -24,9 +24,17 @@
 
 /**
  * @class Tab class for gadgets.
+ * You create tabs using the TabSet addTab() method.
+ * To get Tab objects,
+ * use the TabSet getSelectedTab() or getTabs() methods.
+ *
+ * <p>
+ * <b>See also:</b>
+ * <a href="gadgets.TabSet.html">TabSet</a>
+ * </p>
  *
  * @name gadgets.Tab
- * @description Creates a new Tab
+ * @description Creates a new Tab.
  */
 
 /**
@@ -153,7 +161,7 @@
 
 /**
  * Returns an array of all existing tab objects.
- * @return {Array.<gadgets.Tab>} Array of all existing tab objects.
+ * @return {Array.&lt;gadgets.Tab&gt;} Array of all existing tab objects.
  */
 gadgets.TabSet.prototype.getTabs = function() {
   // TODO

Modified: incubator/shindig/trunk/features/views/views.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/views/views.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================
--- incubator/shindig/trunk/features/views/views.js (original)
+++ incubator/shindig/trunk/features/views/views.js Mon Jan 28 13:42:20 2008
@@ -38,6 +38,8 @@
  * @param {gadgets.views.View} view The view to navigate to
  * @param {Map.&lt;String, String&gt;} opt_params Parameters to pass to the
  *     gadget after it has been navigated to on the surface
+ *
+ * @member gadgets.views
  */
 gadgets.views.requestNavigateTo = function(surface, opt_params) {
   return opensocial.Container.get().requestNavigateTo(surface, opt_params);
@@ -47,6 +49,7 @@
  * Returns the current view.
  *
  * @return {gadgets.views.View} The current view
+ * @member gadgets.views
  */
 gadgets.views.getCurrentView = function() {
   return this.surface;
@@ -58,6 +61,7 @@
  *
  * @return {Map&lt;gadgets.views.ViewType | String, gadgets.views.View&gt;} All
  *   supported views, keyed by their name attribute.
+ * @member gadgets.views
  */
 gadgets.views.getSupportedViews = function() {
   return this.supportedSurfaces;
@@ -69,6 +73,7 @@
  * gadgets.views.requestNavigateTo
  *
  * @return {Map.&lt;String, String&gt;} The parameter map
+ * @member gadgets.views
  */
 gadgets.views.getParams = function() {
   return this.params;
@@ -122,17 +127,23 @@
   * A view where the gadget is displayed in a very large mode. It should be the
   * only thing on the page. In a social context, this is usually called the
   * canvas page.
+  *
+  * @member gadgets.views.ViewType
   */
   FULL_PAGE : 'FULL_PAGE',
 
  /**
   * A view where the gadget is displayed in a small area usually on a page with
   * other gadgets. In a social context, this is usually called the profile page.
+  *
+  * @member gadgets.views.ViewType
   */
   DASHBOARD : 'DASHBOARD',
 
  /**
   * A view where the gadget is displayed in a small separate window by itself.
+  *
+  * @member gadgets.views.ViewType
   */
   POPUP : 'POPUP'
-};
\ No newline at end of file
+};
--- incubator/shindig/trunk/features/core/prefs.js (original)
+++ incubator/shindig/trunk/features/core/prefs.js Mon Jan 28 13:42:20 2008
@@ -46,8 +46,8 @@
 
   /**
    * Returns the module named by moduleId
-   * @param {Number | String} moduleId The module id to fetch.
-   * @return {Object} An object containing module data.
+   * @param {Number | String} moduleId The module id to fetch
+   * @return {Object} An object containing module data
    */
   function getModuleData(moduleId) {
     if (!modules[moduleId]) {
@@ -64,9 +64,9 @@
   /**
    * Adds a new user preference to the stored set for the given module id.
    *
-   * @param {String | Number} moduleId The module id to add the pref for.
-   * @param {String} key The key to add. May be an object where keys = key and
-   *     values = value.
+   * @param {String | Number} moduleId The module id to add the pref for
+   * @param {String} key The key to add; may be an object where keys = key and
+   *     values = value
    * @param {String} opt_value An optional value used to set the value of the
    *     key.
    */
@@ -84,9 +84,9 @@
   /**
    * Adds a new message to the stored set for the given module id.
    *
-   * @param {String | Number} moduleId The module id to add the pref for.
-   * @param {String | Object} key The key to add. May be an object where keys =
-   *     key and values = value.
+   * @param {String | Number} moduleId The module id to add the pref for
+   * @param {String | Object} key The key to add; may be an object where keys =
+   *     key and values = value
    * @param {String} opt_value An optional value used to set the value of the
    *     key.
    */
@@ -106,7 +106,7 @@
   /**
    * Sets the default module id.
    *
-   * @param {String | Number} moduleId The module id to set as default.
+   * @param {String | Number} moduleId The module id to set as default
    */
   function setDefaultModuleId(moduleId) {
     defaultModuleId = moduleId;
@@ -115,7 +115,7 @@
   /**
    * Gets the default module id.
    *
-   * @return {String | Number} The default module id.
+   * @return {String | Number} The default module id
    */
   function getDefaultModuleId() {
     return defaultModuleId;
@@ -124,8 +124,8 @@
   /**
    * Sets the default language for this module id.
    *
-   * @param {String | Number} moduleId The module id to set the language for.
-   * @param {String} language The language code as an ISO 639-1 code.
+   * @param {String | Number} moduleId The module id to set the language for
+   * @param {String} language The language code as an ISO 639-1 code
    */
   function setLanguage(moduleId, language) {
     getModuleData(moduleId).language = language;
@@ -134,8 +134,8 @@
   /**
    * Sets the default country for this module id.
    *
-   * @param {String | Number} moduleId The id of the gagdet instance.
-   * @param {String} country The country code as an ISO 3166-1 alpha-2 code.
+   * @param {String | Number} moduleId The id of the gagdet instance
+   * @param {String} country The country code as an ISO 3166-1 alpha-2 code
    */
   function setCountry(moduleId, country) {
     getModuleData(moduleId).country = country;
@@ -155,12 +155,20 @@
 }();
 
 /**
- * @class A class gadgets can use to get user preference information.
+ * @class 
+ * Provides access to user preferences, module dimensions, and messages.
  *
- * @description Creates a new Prefs object
- * @param {String | Number} opt_moduleId An optional parameters specifying the
- *     module id to create prefs for. If not provided, the default module id
- *     will be used.
+ * Clients can access their preferences by constructing an instance of
+ * gadgets.Prefs and passing in their module id.  Example:
+ *
+<pre>var prefs = new gadgets.Prefs();
+var name = prefs.getString("name");
+var lang = prefs.getLang();</pre>
+ *
+ * @description Creates a new Prefs object.
+ * @param {String | Number} opt_moduleId An optional parameter specifying the
+ *     module id to create prefs for; if not provided, the default module id
+ *     is used
  */
 gadgets.Prefs = function(opt_moduleId) {
   if (typeof opt_moduleId === "undefined") {
@@ -175,11 +183,16 @@
 };
 
 /**
+ * @static
+ * @method
+ * @scope gadgets.Prefs
+ *
  * Static pref parser. Parses all parameters from the url and stores them
  * for later use when creating a new gadgets.Prefs object.
  * You should only ever call this if you are a type=url gadget.
  *
- * @param {String | Number} moduleId The id of the gagdet instance.
+ * @param {String | Number} moduleId The id of the gadget instance
+ * @private
  */
 gadgets.Prefs.parseUrl = function(moduleId) {
   var prefs = {};
@@ -211,8 +224,8 @@
 
 /**
  * Internal helper for pref fetching.
- * @param {String} key The key to fetch.
- * @return {Object?} The preference.
+ * @param {String} key The key to fetch
+ * @return {Object} The preference
  * @private
  */
 gadgets.Prefs.prototype.getPref_ = function(key) {
@@ -222,8 +235,8 @@
 
 /**
  * Retrieves a string preference.
- * @param {String} key The preference to fetch.
- * @return {String} The preference. If not set, an empty string.
+ * @param {String} key The preference to fetch
+ * @return {String} The preference; if not set, an empty string
  */
 gadgets.Prefs.prototype.getString = function(key) {
   var val = this.getPref_(key);
@@ -232,8 +245,8 @@
 
 /**
  * Retrieves an integer preference.
- * @param {String} key The preference to fetch.
- * @return {Number} The preference. If not set, 0.
+ * @param {String} key The preference to fetch
+ * @return {Number} The preference; if not set, 0
  */
 gadgets.Prefs.prototype.getInt = function(key) {
   var val = parseInt(this.getPref_(key), 10);
@@ -241,9 +254,9 @@
 };
 
 /**
- * Retrieves a floating point preference.
- * @param {String} key The preference to fetch.
- * @return {Number} The preference. If not set, 0.
+ * Retrieves a floating-point preference.
+ * @param {String} key The preference to fetch
+ * @return {Number} The preference; if not set, 0
  */
 gadgets.Prefs.prototype.getFloat = function(key) {
   var val = parseFloat(this.getPref_(key));
@@ -252,8 +265,8 @@
 
 /**
  * Retrieves a boolean preference.
- * @param {String} key The preference to fetch.
- * @return {Boolean} The preference. If not set, false.
+ * @param {String} key The preference to fetch
+ * @return {Boolean} The preference; if not set, false
  */
 gadgets.Prefs.prototype.getBool = function(key) {
   var val = this.getPref_(key);
@@ -265,13 +278,17 @@
 
 /**
  * Stores a preference.
- * Note: If the gadget needs to store an Array it should use setArray instead of
+ * To use this call,
+ * the gadget must require the feature setprefs.
+ *
+ * <p class="note">
+ * <b>Note:</b>
+ * If the gadget needs to store an Array it should use setArray instead of
  * this call.
- * Note: The gadget must require the feature setprefs in
- * order to use this call.
+ * </p>
  *
- * @param {String} key The pref to store.
- * @param {Object} val The values to store.
+ * @param {String} key The pref to store
+ * @param {Object} val The values to store
  */
 gadgets.Prefs.prototype.set = function(key, value) {
   throw new Error("setprefs feature required to make this call.");
@@ -279,10 +296,11 @@
 
 /**
  * Retrieves an array preference.
- * @param {String} key The preference to fetch.
- * @return {Array.<String>} The preference. If not set, an empty array.
- *     UserPref values that were not declared as lists will be treated as
- *     1 element arrays.
+ * UserPref values that were not declared as lists are treated as
+ * one-element arrays.
+ *
+ * @param {String} key The preference to fetch
+ * @return {Array.&lt;String&gt;} The preference; if not set, an empty array
  */
 gadgets.Prefs.prototype.getArray = function(key) {
   var val = this.getPref_(key);
@@ -298,11 +316,12 @@
 };
 
 /**
- * Stores an array preference. The gadget must require the feature setprefs in
- * order to use this call.
+ * Stores an array preference.
+ * To use this call,
+ * the gadget must require the feature setprefs.
  *
- * @param {String} key The pref to store.
- * @param {Array} val The values to store.
+ * @param {String} key The pref to store
+ * @param {Array} val The values to store
  */
 gadgets.Prefs.prototype.setArray = function(key, val) {
   throw new Error("setprefs feature required to make this call.");
@@ -311,7 +330,7 @@
 /**
  * Fetches an unformatted message.
  * @param {String} key The message to fetch
- * @return {String} The message.
+ * @return {String} The message
  */
 gadgets.Prefs.prototype.getMsg = function(key) {
   var val = this.msgs_[key];
@@ -353,11 +372,10 @@
  * Returns a message value with the positional argument opt_subst in place if
  * it is provided or the provided example value if it is not, or the empty
  * string if the message is not found.
- * Eventually we may provide controls to return different default messages.
  *
- * @param {String} key The message to fetch.
- * @param {String} opt_subst An optional string to substitute into the message.
- * @return {String} The formatted string.
+ * @param {String} key The message to fetch
+ * @param {String} opt_subst An optional string to substitute into the message
+ * @return {String} The formatted string
  */
 gadgets.Prefs.prototype.getMsgFormatted = function(key, opt_subst) {
   var val = this.getMsg(key);
@@ -377,7 +395,7 @@
 /**
  * Gets the current country, returned as ISO 3166-1 alpha-2 code.
  *
- * @return {String} The country for this module instance.
+ * @return {String} The country for this module instance
  */
 gadgets.Prefs.prototype.getCountry = function() {
   return this.data_.country;
@@ -387,7 +405,7 @@
  * Gets the current language the gadget should use when rendering, returned as a
  * ISO 639-1 language code.
  *
- * @return {String} The language for this module instance.
+ * @return {String} The language for this module instance
  */
 gadgets.Prefs.prototype.getLang = function() {
   return this.data_.language;
@@ -396,7 +414,7 @@
 /**
  * Gets the module id for the current instance.
  *
- * @return {String | Number} The module id for this module instance.
+ * @return {String | Number} The module id for this module instance
  */
 gadgets.Prefs.prototype.getModuleId = function() {
   return this.moduleId_;

Modified: incubator/shindig/trunk/features/core/util.js
URL: http://svn.apache.org/viewvc/incubator/shindig/trunk/features/core/util.js?rev=616061&r1=616060&r2=616061&view=diff
==============================================================================